==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/ManagedDatabaseSensitivityLabel.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [ManagedDatabaseSensitivityLabel].
 */
@PulumiTagMarker
public class ManagedDatabaseSensitivityLabelResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ManagedDatabaseSensitivityLabelArgs = ManagedDatabaseSensitivityLabelArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ManagedDatabaseSensitivityLabelArgsBuilder.() -> Unit) {
        val builder = ManagedDatabaseSensitivityLabelArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ManagedDatabaseSensitivityLabel {
        val builtJavaResource =
            com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ManagedDatabaseSensitivityLabel(builtJavaResource)
    }
}

/**
 * A sensitivity label.
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2020-11-01-preview.
 * Other available API versions: 2022-11-01-preview, 2023-02-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### Updates or creates a sensitivity label of a given column with all parameters in a managed database
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var managedDatabaseSensitivityLabel = new AzureNative.Sql.ManagedDatabaseSensitivityLabel("managedDatabaseSensitivityLabel", new()
 *     {
 *         ColumnName = "myColumn",
 *         DatabaseName = "myDatabase",
 *         InformationType = "PhoneNumber",
 *         InformationTypeId = "d22fa6e9-5ee4-3bde-4c2b-a409604c4646",
 *         LabelId = "bf91e08c-f4f0-478a-b016-25164b2a65ff",
 *         LabelName = "PII",
 *         ManagedInstanceName = "myManagedInstanceName",
 *         Rank = AzureNative.Sql.SensitivityLabelRank.High,
 *         ResourceGroupName = "myRG",
 *         SchemaName = "dbo",
 *         SensitivityLabelSource = "current",
 *         TableName = "myTable",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewManagedDatabaseSensitivityLabel(ctx, "managedDatabaseSensitivityLabel", &sql.ManagedDatabaseSensitivityLabelArgs{
 * 			ColumnName:             pulumi.String("myColumn"),
 * 			DatabaseName:           pulumi.String("myDatabase"),
 * 			InformationType:        pulumi.String("PhoneNumber"),
 * 			InformationTypeId:      pulumi.String("d22fa6e9-5ee4-3bde-4c2b-a409604c4646"),
 * 			LabelId:                pulumi.String("bf91e08c-f4f0-478a-b016-25164b2a65ff"),
 * 			LabelName:              pulumi.String("PII"),
 * 			ManagedInstanceName:    pulumi.String("myManagedInstanceName"),
 * 			Rank:                   sql.SensitivityLabelRankHigh,
 * 			ResourceGroupName:      pulumi.String("myRG"),
 * 			SchemaName:             pulumi.String("dbo"),
 * 			SensitivityLabelSource: pulumi.String("current"),
 * 			TableName:              pulumi.String("myTable"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel;
 * import com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabelArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var managedDatabaseSensitivityLabel = new ManagedDatabaseSensitivityLabel("managedDatabaseSensitivityLabel", ManagedDatabaseSensitivityLabelArgs.builder()
 *             .columnName("myColumn")
 *             .databaseName("myDatabase")
 *             .informationType("PhoneNumber")
 *             .informationTypeId("d22fa6e9-5ee4-3bde-4c2b-a409604c4646")
 *             .labelId("bf91e08c-f4f0-478a-b016-25164b2a65ff")
 *             .labelName("PII")
 *             .managedInstanceName("myManagedInstanceName")
 *             .rank("High")
 *             .resourceGroupName("myRG")
 *             .schemaName("dbo")
 *             .sensitivityLabelSource("current")
 *             .tableName("myTable")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:ManagedDatabaseSensitivityLabel current /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/managedInstances/{managedInstanceName}/databases/{databaseName}/schemas/{schemaName}/tables/{tableName}/columns/{columnName}/sensitivityLabels/{sensitivityLabelSource}
 * ```
 */
public class ManagedDatabaseSensitivityLabel internal constructor(
    override val javaResource: com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel,
) : KotlinCustomResource(javaResource, ManagedDatabaseSensitivityLabelMapper) {
    /**
     * The column name.
     */
    public val columnName: Output<String>
        get() = javaResource.columnName().applyValue({ args0 -> args0 })

    /**
     * The information type.
     */
    public val informationType: Output<String>?
        get() = javaResource.informationType().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The information type ID.
     */
    public val informationTypeId: Output<String>?
        get() = javaResource.informationTypeId().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Is sensitivity recommendation disabled. Applicable for recommended sensitivity label only. Specifies whether the sensitivity recommendation on this column is disabled (dismissed) or not.
     */
    public val isDisabled: Output<Boolean>
        get() = javaResource.isDisabled().applyValue({ args0 -> args0 })

    /**
     * The label ID.
     */
    public val labelId: Output<String>?
        get() = javaResource.labelId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The label name.
     */
    public val labelName: Output<String>?
        get() = javaResource.labelName().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource that manages the sensitivity label.
     */
    public val managedBy: Output<String>
        get() = javaResource.managedBy().applyValue({ args0 -> args0 })

    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    public val rank: Output<String>?
        get() = javaResource.rank().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The schema name.
     */
    public val schemaName: Output<String>
        get() = javaResource.schemaName().applyValue({ args0 -> args0 })

    /**
     * The table name.
     */
    public val tableName: Output<String>
        get() = javaResource.tableName().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ManagedDatabaseSensitivityLabelMapper :
    ResourceMapper<ManagedDatabaseSensitivityLabel> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel::class == javaResource::class

    override fun map(javaResource: Resource): ManagedDatabaseSensitivityLabel =
        ManagedDatabaseSensitivityLabel(
            javaResource as
                com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel,
        )
}

/**
 * @see [ManagedDatabaseSensitivityLabel].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ManagedDatabaseSensitivityLabel].
 */
public suspend fun managedDatabaseSensitivityLabel(
    name: String,
    block: suspend ManagedDatabaseSensitivityLabelResourceBuilder.() -> Unit,
):
    ManagedDatabaseSensitivityLabel {
    val builder = ManagedDatabaseSensitivityLabelResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ManagedDatabaseSensitivityLabel].
 * @param name The _unique_ name of the resulting resource.
 */
public fun managedDatabaseSensitivityLabel(name: String): ManagedDatabaseSensitivityLabel {
    val builder = ManagedDatabaseSensitivityLabelResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/ManagedDatabaseSensitivityLabel.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [ManagedDatabaseSensitivityLabel].
 */
@PulumiTagMarker
public class ManagedDatabaseSensitivityLabelResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ManagedDatabaseSensitivityLabelArgs = ManagedDatabaseSensitivityLabelArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ManagedDatabaseSensitivityLabelArgsBuilder.() -> Unit) {
        val builder = ManagedDatabaseSensitivityLabelArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ManagedDatabaseSensitivityLabel {
        val builtJavaResource =
            com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ManagedDatabaseSensitivityLabel(builtJavaResource)
    }
}

/**
 * A sensitivity label.
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2020-11-01-preview.
 * Other available API versions: 2022-11-01-preview, 2023-02-01-preview, 2023-05-01-preview, 2023-08-01-preview.
 * ## Example Usage
 * ### Updates or creates a sensitivity label of a given column with all parameters in a managed database
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var managedDatabaseSensitivityLabel = new AzureNative.Sql.ManagedDatabaseSensitivityLabel("managedDatabaseSensitivityLabel", new()
 *     {
 *         ColumnName = "myColumn",
 *         DatabaseName = "myDatabase",
 *         InformationType = "PhoneNumber",
 *         InformationTypeId = "d22fa6e9-5ee4-3bde-4c2b-a409604c4646",
 *         LabelId = "bf91e08c-f4f0-478a-b016-25164b2a65ff",
 *         LabelName = "PII",
 *         ManagedInstanceName = "myManagedInstanceName",
 *         Rank = AzureNative.Sql.SensitivityLabelRank.High,
 *         ResourceGroupName = "myRG",
 *         SchemaName = "dbo",
 *         SensitivityLabelSource = "current",
 *         TableName = "myTable",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewManagedDatabaseSensitivityLabel(ctx, "managedDatabaseSensitivityLabel", &sql.ManagedDatabaseSensitivityLabelArgs{
 * 			ColumnName:             pulumi.String("myColumn"),
 * 			DatabaseName:           pulumi.String("myDatabase"),
 * 			InformationType:        pulumi.String("PhoneNumber"),
 * 			InformationTypeId:      pulumi.String("d22fa6e9-5ee4-3bde-4c2b-a409604c4646"),
 * 			LabelId:                pulumi.String("bf91e08c-f4f0-478a-b016-25164b2a65ff"),
 * 			LabelName:              pulumi.String("PII"),
 * 			ManagedInstanceName:    pulumi.String("myManagedInstanceName"),
 * 			Rank:                   sql.SensitivityLabelRankHigh,
 * 			ResourceGroupName:      pulumi.String("myRG"),
 * 			SchemaName:             pulumi.String("dbo"),
 * 			SensitivityLabelSource: pulumi.String("current"),
 * 			TableName:              pulumi.String("myTable"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel;
 * import com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabelArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var managedDatabaseSensitivityLabel = new ManagedDatabaseSensitivityLabel("managedDatabaseSensitivityLabel", ManagedDatabaseSensitivityLabelArgs.builder()
 *             .columnName("myColumn")
 *             .databaseName("myDatabase")
 *             .informationType("PhoneNumber")
 *             .informationTypeId("d22fa6e9-5ee4-3bde-4c2b-a409604c4646")
 *             .labelId("bf91e08c-f4f0-478a-b016-25164b2a65ff")
 *             .labelName("PII")
 *             .managedInstanceName("myManagedInstanceName")
 *             .rank("High")
 *             .resourceGroupName("myRG")
 *             .schemaName("dbo")
 *             .sensitivityLabelSource("current")
 *             .tableName("myTable")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:ManagedDatabaseSensitivityLabel current /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/managedInstances/{managedInstanceName}/databases/{databaseName}/schemas/{schemaName}/tables/{tableName}/columns/{columnName}/sensitivityLabels/{sensitivityLabelSource}
 * ```
 */
public class ManagedDatabaseSensitivityLabel internal constructor(
    override val javaResource: com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel,
) : KotlinCustomResource(javaResource, ManagedDatabaseSensitivityLabelMapper) {
    /**
     * The column name.
     */
    public val columnName: Output<String>
        get() = javaResource.columnName().applyValue({ args0 -> args0 })

    /**
     * The information type.
     */
    public val informationType: Output<String>?
        get() = javaResource.informationType().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The information type ID.
     */
    public val informationTypeId: Output<String>?
        get() = javaResource.informationTypeId().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * Is sensitivity recommendation disabled. Applicable for recommended sensitivity label only. Specifies whether the sensitivity recommendation on this column is disabled (dismissed) or not.
     */
    public val isDisabled: Output<Boolean>
        get() = javaResource.isDisabled().applyValue({ args0 -> args0 })

    /**
     * The label ID.
     */
    public val labelId: Output<String>?
        get() = javaResource.labelId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The label name.
     */
    public val labelName: Output<String>?
        get() = javaResource.labelName().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource that manages the sensitivity label.
     */
    public val managedBy: Output<String>
        get() = javaResource.managedBy().applyValue({ args0 -> args0 })

    /**
     * Resource name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    public val rank: Output<String>?
        get() = javaResource.rank().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The schema name.
     */
    public val schemaName: Output<String>
        get() = javaResource.schemaName().applyValue({ args0 -> args0 })

    /**
     * The table name.
     */
    public val tableName: Output<String>
        get() = javaResource.tableName().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ManagedDatabaseSensitivityLabelMapper :
    ResourceMapper<ManagedDatabaseSensitivityLabel> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel::class == javaResource::class

    override fun map(javaResource: Resource): ManagedDatabaseSensitivityLabel =
        ManagedDatabaseSensitivityLabel(
            javaResource as
                com.pulumi.azurenative.sql.ManagedDatabaseSensitivityLabel,
        )
}

/**
 * @see [ManagedDatabaseSensitivityLabel].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ManagedDatabaseSensitivityLabel].
 */
public suspend fun managedDatabaseSensitivityLabel(
    name: String,
    block: suspend ManagedDatabaseSensitivityLabelResourceBuilder.() -> Unit,
):
    ManagedDatabaseSensitivityLabel {
    val builder = ManagedDatabaseSensitivityLabelResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ManagedDatabaseSensitivityLabel].
 * @param name The _unique_ name of the resulting resource.
 */
public fun managedDatabaseSensitivityLabel(name: String): ManagedDatabaseSensitivityLabel {
    val builder = ManagedDatabaseSensitivityLabelResourceBuilder()
    builder.name(name)
    return builder.build()
}
